@@ -32,7 +32,7 @@ use Expect;
 use Term::ReadLine;
 use Term::ReadPassword;
 
-use constant CMD_TIMEOUT_SEC    => 2;
+use constant CMD_TIMEOUT_SEC    => 5;
 use constant MAKE_TIMEOUT_SEC   => 3600;
 use constant WINDOWS_HOSTNAME   => 'brazil';
 use constant VSVARS2003_PATH    => 'C:/Develop/IDE/VisualStudio2003/Common7/Tools/vsvars32.bat';
@@ -55,7 +55,7 @@ sub ssh_login {
     my $exp = shift;
     my $pass = shift;
 
-    $exp->spawn('ssh', WINDOWS_HOSTNAME) or die $!;
+    $exp->spawn('cocot', qw(-t EUC-JP -p CP932 ssh), WINDOWS_HOSTNAME) or die $!;
     $exp->expect(CMD_TIMEOUT_SEC, 'password:');
     $exp->send($pass . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, 'successfully');
@@ -67,7 +67,7 @@ sub mount_disk {
     my $pass = shift;
 
     $exp->send('net use ' . DISK_DEVICE . ' ' . quotemeta(DISK_PATH) .
-               ' /USER:' . $user . " | nkf -e\n");
+               ' /USER:' . $user . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, '$ ');
 }
 
@@ -86,14 +86,14 @@ sub cd_src_dir {
     my $exp = shift;
 
     $exp->send('cd $base_dir/src' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, 'src>');
+    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
 }
 
 sub cd_util_dir {
     my $exp = shift;
 
     $exp->send('cd $base_dir/util' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, 'util>');
+    $exp->expect(CMD_TIMEOUT_SEC, '$ ');
 }
 
 sub set_module_env {
@@ -110,22 +110,22 @@ sub exit_cmd {
     my $exp = shift;
 
     $exp->send('exit' . "\n");
-    $exp->expect(MAKE_TIMEOUT_SEC, '$');
+    $exp->expect(MAKE_TIMEOUT_SEC, '$ ');
 }
 
 sub compile_module {
     my $exp = shift;
 
-    $exp->send('make -f GNUmakefile.win32 clean 2>&1 | nkf -e' . "\n");
+    $exp->send('make -f GNUmakefile.win32 clean' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
 
-    $exp->send('make -f GNUmakefile.win32 mod_uploader-ap2.0.so 2>&1 | nkf -e' . "\n");
+    $exp->send('make -f GNUmakefile.win32 mod_uploader-ap2.0.so' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
 
-    $exp->send('make -f GNUmakefile.win32 clean-obj 2>&1 | nkf -e' . "\n");
+    $exp->send('make -f GNUmakefile.win32 clean-obj' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
 
-    $exp->send('make -f GNUmakefile.win32 mod_uploader-ap2.2.so 2>&1 | nkf -e' . "\n");
+    $exp->send('make -f GNUmakefile.win32 mod_uploader-ap2.2.so' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
 }
 
@@ -142,14 +142,14 @@ sub set_installer_env {
 sub compile_utility {
     my $exp = shift;
 
-    $exp->send('msbuild UploaderConfig/UploaderConfig.csproj /p:Configuration=Release /t:Rebuild 2>&1 | nkf -e' . "\n");
+    $exp->send('msbuild UploaderConfig/UploaderConfig.csproj /p:Configuration=Release /t:Rebuild 2>&1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'util>');
 }
 
 sub compile_installer {
     my $exp = shift;
 
-    $exp->send('devenv /build release UploaderConfigSetup/UploaderConfigSetup.vdproj 2>&1 | nkf -e' . "\n");
+    $exp->send('devenv /build release UploaderConfigSetup/UploaderConfigSetup.vdproj 2>&1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'util>');
 }
 
@@ -205,6 +205,8 @@ exit_cmd($exp);
 # ХʥեΥԡ
 copy_binary($exp);
 
+`rm -rf work $temp_dir`;
+
 # Local Variables:
 # mode: cperl
 # coding: euc-japan-unix
